@@ -8,8 +8,8 @@ class TeardownResult(Result):
 
     kind = "generic"
 
-    def __init__(self, passed: bool = True, complete: bool = True, **details):
-        super().__init__(complete=complete, passed=passed, details=details)
+    def __init__(self, passing: bool = True, complete: bool = True, **details):
+        super().__init__(complete=complete, passing=passing, details=details)
 
 
 class TeardownStage(GraderStage):
@@ -20,9 +20,9 @@ class TeardownStage(GraderStage):
     def generic(self, **details) -> Registrar:
         """Generic tasks."""
 
-        return self.create_registrar(details, TeardownResult)
+        return self.registrar(details, TeardownResult)
 
     def cleanup(self, **details) -> Registrar:
         """Deleting files."""
 
-        return self.create_registrar(details, CleanupResult)
+        return self.registrar(details, CleanupResult)
