@@ -4,7 +4,7 @@ from typing import *
 from pathlib import Path
 
 from . import CorrectnessResult
-from .. import Test, Result
+from .. import Test
 from ...task import Error
 from ....library.process import Runtime, Interactive, InteractiveStreamTimeoutExpired, Interaction
 from ....library.configurable import none, not_none, Configurable
@@ -125,35 +125,31 @@ class CompareBytesOutputTest(OutputTest, Configurable):
         """
 
         super().__init__(**kwargs)
-        self.test_out = test_out
-        self.test_out_lines = test_out_lines
-        self.test_out_lines_lists = test_out_lines_lists
+        self.test_out = self.resolve("test_out", local=test_out, default=None)
+        self.test_out_lines = self.resolve("test_out_lines", local=test_out_lines, default=None)
+        self.test_out_lines_lists = self.resolve("test_out_lines_lists", local=test_out_lines_lists, default=None)
 
         # Check resolvable
-        resolvable = tuple(filter(None, map(self.is_resolvable, (
-            "test_out",
-            "test_out_lines",
-            "test_out_lines_lists"))))
+        resolvable = tuple(filter(None, (self.test_out, self.test_out_lines, self.test_out_lines_lists)))
         if len(resolvable) != 1:
             raise ValueError("Exactly one of test_out, test_out_lines, or test_out_lines_lists is required")
 
-        self.out_transform = out_transform
-        self.out_line_transform = out_line_transform
+        self.out_transform = self.resolve("out_transform", local=out_transform, default=identity)
+        self.out_line_transform = self.resolve("out_line_transform", local=out_line_transform, default=identity)
 
     def test(self, out: bytes):
         """Call the corresponding test."""
 
-        if self.is_resolvable("test_out"):
+        if self.test_out is not None:
             return self._test_out(out)
         return self._test_out_lines_lists(out)
 
     def _test_out(self, out: bytes) -> CorrectnessResult:
         """Shortcut compare for one option block text."""
 
-        out_transform = self.resolve("out_transform", default=identity)
         test_out = self.resolve("test_out")
 
-        out = out_transform(out)
+        out = self.out_transform(out)
         passing = out == test_out
         error = None if passing else Error(
             description="unexpected output",
@@ -164,15 +160,12 @@ class CompareBytesOutputTest(OutputTest, Configurable):
     def _test_out_lines_lists(self, out: bytes) -> CorrectnessResult:
         """Used to compare multiple options of lists of lines."""
 
-        out_transform = self.resolve("out_transform", default=identity)
-        out_line_transform = self.resolve("out_line_transform", default=identity)
-        test_out_lines = self.resolve("test_out_lines", default=None)
-        if test_out_lines is not None:
-            test_out_lines_lists = [test_out_lines]
+        if self.test_out_lines is not None:
+            test_out_lines_lists = [self.test_out_lines]
         else:
-            test_out_lines_lists = self.resolve("test_out_lines_lists")
+            test_out_lines_lists = self.test_out_lines_lists
 
-        out_lines = tuple(map(out_line_transform, out_transform(out).split(b"\n")))
+        out_lines = tuple(map(self.out_line_transform, self.out_transform(out).split(b"\n")))
         passing = any(lines_match(out_lines, lines) for lines in test_out_lines_lists)
         error = None if passing else Error(
             description="unexpected output",
@@ -183,22 +176,22 @@ class CompareBytesOutputTest(OutputTest, Configurable):
         return CorrectnessResult(passing=passing, error=error)
 
 
-def test_runtime_succeeded(runtime: Runtime, result_type):
+def test_runtime_succeeded(runtime: Runtime) -> CorrectnessResult:
     """See if the runtime raised exceptions or returned status code."""
 
     if runtime.raised_exception:
         error = Error(description=runtime.exception.description)
-        raise result_type(passing=False, runtime=runtime.dump(), error=error)
+        raise CorrectnessResult(passing=False, runtime=runtime.dump(), error=error)
     if runtime.timed_out:
         error = Error(
             description="timed out",
             suggestion=f"expected maximum elapsed time of {runtime.timeout} seconds")
-        raise result_type(passing=False, runtime=runtime.dump(), error=error)
+        raise CorrectnessResult(passing=False, runtime=runtime.dump(), error=error)
     if runtime.code != 0:
         error = Error(
             description=f"received status code {runtime.code}",
             suggestion="expected status code of zero")
-        raise result_type(passing=False, runtime=runtime.dump(), error=error)
+        return CorrectnessResult(passing=False, runtime=runtime.dump(), error=error)
 
 
 class ExecutableMixin(OutputTest, Configurable):
@@ -297,18 +290,24 @@ class ExecutableOutputFileMixin(OutputTest, Configurable):
 CompareNativeTest = Callable[[Any], CorrectnessResult]
 
 
-class CompareExitCodeOutputTest(OutputTest):
+class CompareExitCodeOutputTest(OutputTest, Configurable):
     """Checks program exit code."""
 
     test: CompareNativeTest
     resources: Optional[dict]
     details: Optional[dict]
 
-    def __init__(self, *, expected_code: int = None, expected_codes: Container[int] = None, **kwargs):
+    expected_code: int
+    expected_codes: Container[int]
+
+    def __init__(self, *, expected_code: int = none, expected_codes: Container[int] = none, **kwargs):
         """Set expected codes."""
 
         super().__init__(**kwargs)
 
+        expected_code = self.resolve("expected_code", local=expected_code, default=None)
+        expected_codes = self.resolve("expected_codes", local=expected_codes, default=None)
+
         if expected_code is None and expected_codes is None:
             raise ValueError("Runtime exit test requires either expected status or statuses!")
         if expected_code is not None:
