@@ -143,8 +143,6 @@ def summarize(grading_path: Path, report_paths: Iterable[Path]):
             if count_tests_complete:
                 count_tests_passing = len(filter_tests(student_summary.problems[problem_short].tasks_passing))
                 scores.append(count_tests_passing / count_tests_complete)
-                if count_tests_passing == 0:
-                    print(student_username)
                 # print(student_username, 100 * count_tests_passing / count_tests_complete)
 
         print("  Statistics")
@@ -152,7 +150,6 @@ def summarize(grading_path: Path, report_paths: Iterable[Path]):
         print(f"    Mean: {percent(statistics.mean(scores)) if len(scores) > 0 else '-'}")
         print(f"    Median: {percent(statistics.median(scores)) if len(scores) > 0 else '-'}")
         print(f"    Perfect: {percent(len(list(filter(lambda x: x == 1, scores))), len(scores))}")
-        print(f"    None: {percent(len(list(filter(lambda x: x == 0, scores))), len(scores))}")
         # print(f"    Scores: {list(scores)}")
 
     print(f"Submissions that failed setup: {len(summary.failed_setup)}")
